@@ -26,6 +26,6 @@ class Regions:
 
         if filter:
             data = r.json()
-            return filter_list(data=data, filter=filter)
+            return filter_list(data=data, filter_by=filter)
 
         return r.json()
